@@ -386,12 +386,17 @@ def auto_generate_testcase_list_from_csv(call_by_doctor=False):
 
                     with open(csv_file_full_path) as f:
                         f_csv = csv.DictReader(f)
-                        index = 0
 
-                        for row in f_csv:
-                            index += 1
+                        reversed_f_csv = []
+                        for r in f_csv:
+                            reversed_f_csv.append(r)
+
+                        index = len(reversed_f_csv)
+
+                        for row in reversed_f_csv[::-1]:
                             py_file_name = file_name.split(".")[0] + ".py"
                             generate_testcase_list_by_csv(csv_file_full_path, row, index, is_ui_testcase, tag_name=tag_name)
+                            index -= 1
 
 
 if __name__ == "__main__":
