@@ -4,11 +4,12 @@ import traceback
 import json
 
 # import threading
-from .logged_requests import LoggedRequests
+# from .logged_requests import LoggedRequests
 
 from pprint import pformat
 from pprint import pprint
 from jsoncomparison import Compare
+import requests
 
 try:
     import settings
@@ -41,7 +42,8 @@ BaseTestCase is the superclass for all the backend(Non UI) and frontend(UI) Test
         self.pformat = pformat
         self.logger = logging
 
-        self.requests = LoggedRequests
+        # self.requests = LoggedRequests
+        self.requests = requests
 
         self.testcase_id = None
 
