@@ -32,12 +32,16 @@ def log_curl(func):
 
     def wrapper(*args, **kw):
         self = None
-        from . import base_testcase
+        from .base_testcase import BaseTestCase
 
+        #
         for item in args:
-            if isinstance(item, base_testcase.BaseTestCase):
-                self = item
-                break
+            try:
+                if isinstance(item.this, BaseTestCase):
+                    self = item.this
+                    break
+            except BaseException:
+                pass
 
         res = func(*args, **kw)
 
@@ -63,29 +67,16 @@ def log_curl(func):
 
 
 class LoggedRequests:
+    def __init__(self, executing_case):
+        self.this = executing_case
     """
     封装 requests module 的常用方法，自动log 每次 request 的参数 & response 内容
     @author: Wang Lin
     """
 
-    @staticmethod
     @log_curl
-    def get(self=None, url=None, params=None, **kwargs):
-        '''
-        self， 如果为None, 则此方法 等价于 开源 requests.get()方法， 否则 会log 此请求的参数 & 响应值
-        '''
-
-        if type(self) == str:
-            url = self
-
-            # call requests.get()
-            response = requests.get(url, params, **kwargs)
-            return response
-
-        if self is None:
-            # call requests.get()
-            response = requests.get(url, params, **kwargs)
-            return response
+    def get(self, url, params=None, **kwargs):
+        self = self.this
 
         # 增加此判断逻辑，解释参见 post 方法
         if hasattr(settings, "auto_log_request") and settings.auto_log_request is False:
@@ -124,37 +115,10 @@ class LoggedRequests:
 
         return response
 
-    @staticmethod
     @log_curl
-    def post(self=None, url=None, data=None, json=None, **kwargs):
-        '''
-        self， 如果为None, 则此方法 等价于 开源 requests.post()方法， 否则 会自动写入 此请求的参数 & 响应值
-        '''
+    def post(self, url, data=None, json=None, **kwargs):
+        self = self.this
 
-        if type(self) == str:
-            url = self
-
-            # 直接调用 开源 requests
-            response = requests.post(url, data, json, **kwargs)
-            return response
-
-        if self is None:
-            response = requests.post(url, data, json, **kwargs)
-            return response
-
-        # 如果调用方式为  self.requests.post(
-        #                   self,
-        #                   "%s/login" % settings.SERVER_URL,
-        #                   data=json.dumps(post_data),
-        #                   headers=headers)
-        # 并且 此时 很有可能 该调用方法之前 已经明确的 手工调用了 self.logger.info("xxxx..."), 只有传入的 self is not None，
-        # 代码逻辑 才会执行到 此处！
-        # eg:
-        #     self.logger.info("social_login headers: ")
-        #     self.logger.info(self.pformat(headers))
-        #     self.logger.info("social_login post_data: ")
-        #     self.logger.info(self.pformat(post_data))
-        #     self.logger.info("social_login api: xxx/login")
         #  为了 不重复记录 log,则 增加如下判断， 如果 settings.auto_log_request = False, 则不需要框架自动记录log!
         if hasattr(settings, "auto_log_request") and settings.auto_log_request is False:
             # 直接调用 开源 requests
@@ -211,23 +175,9 @@ class LoggedRequests:
 
         return response
 
-    @staticmethod
     @log_curl
-    def put(self=None, url=None, data=None, **kwargs):
-        '''
-        self， 如果为None, 则此方法 等价于 开源 requests.put()方法， 否则 会自动写入 此请求的参数 & 响应值
-        '''
-
-        if type(self) == str:
-            url = self
-
-            # 直接调用 开源 requests
-            response = requests.put(url, data, **kwargs)
-            return response
-
-        if self is None:
-            response = requests.put(url, data, **kwargs)
-            return response
+    def put(self, url, data=None, **kwargs):
+        self = self.this
 
         # 增加此判断逻辑，解释参见 post 方法
         if hasattr(settings, "auto_log_request") and settings.auto_log_request is False:
@@ -268,24 +218,10 @@ class LoggedRequests:
 
         return response
 
-    @staticmethod
     @log_curl
-    def delete(self=None, url=None, **kwargs):
-        '''
-        self， 如果为None, 则此方法 等价于 开源 requests.delete()方法， 否则 会自动写入 此请求的参数 & 响应值
-        '''
-
-        if type(self) == str:
-            url = self
-
-            # 直接调用 开源 requests
-            response = requests.delete(url, **kwargs)
-            return response
-
-        if self is None:
-            response = requests.delete(url, **kwargs)
-            return response
-
+    def delete(self, url, **kwargs):
+        self = self.this
+        
         # 增加此判断逻辑，解释参见 post 方法
         if hasattr(settings, "auto_log_request") and settings.auto_log_request is False:
             # 直接调用 开源 requests
